@@ -4,7 +4,6 @@
 # imports.
 from dev0s.classes.defaults.objects import *
 from dev0s.classes.defaults.defaults import defaults
-from dev0s.classes.code.docs import Docs
 from dev0s.classes.defaults.exceptions import Exceptions
 from dev0s.classes.response import response as _response_
 from dev0s.classes import code
@@ -20,10 +19,10 @@ class Database(Traceback):
 	):
 		
 		# docs.
-		Docs.__init__(self,
-			initialized=False,
-			module="dev0s.database.Database", 
-			notes=[], )
+		DOCS = {
+			"module":"dev0s.database.Database", 
+			"initialized":False,
+			"description":[], }
 
 		# traceback.
 		Traceback.__init__(self, traceback="Database")
@@ -180,10 +179,10 @@ class WebServer(Thread):
 	):
 
 		# docs.
-		Docs.__init__(self,
-			initialized=False,
-			module="dev0s.database.WebServer", 
-			notes=[], )
+		DOCS = {
+			"module":"dev0s.database.WebServer", 
+			"initialized":False,
+			"description":[], }
 
 		# defaults.
 		Thread.__init__(self)
