@@ -503,23 +503,78 @@ class ResponseObject(object):
 		},
 	):
 
-		# check self instance.
-		if isinstance(attributes, ResponseObject):
-			attributes = attributes.dict()
-		elif attributes.__class__.__name__ in ["OutputObject"]:
-			attributes = attributes.response()
-		elif isinstance(attributes, (str,String)):
-				try:
-					self.assign(pypi_json.loads(attributes))
-				except:
+		# serialize attributes to dict.
+		def serialize(attributes, all_formats_allowed=False):
+			if isinstance(attributes, ResponseObject):
+				attributes = attributes.dict()
+			elif attributes.__class__.__name__ in ["OutputObject"]:
+				attributes = attributes.response().dict()
+			elif isinstance(attributes, (dict,Dictionary)):
+				attributes = attributes
+			elif isinstance(attributes, (str,String)):
+				if attributes in ["true", "True", "TRUE", True]:
+					attributes = True
+				elif attributes in ["false", "False", "FALSE", False]:
+					attributes = False
+				elif attributes in ["null", "None", "Nan", None]:
+					attributes = None
+				else:
+					integer = None
 					try:
-						self.assign(ast.literal_eval(attributes))
+						if "." in attributes:
+							integer = float(attributes)
+						else:
+							integer = int(attributes)
 					except:
-						self.assign(pypi_json.loads(String(attributes).slice_dict()))
-		elif isinstance(attributes, (dict,Dictionary)):
-			self.assign(attributes)
-		else:
-			raise Exceptions.InvalidUsage(f"<ResponseObject.attributes>: parameter [attributes] must be a [dict, dict in str format], not [{attributes.__class__.__name__}].")
+						integer = None
+					if integer != None:
+						attributes = integer
+					else:
+						try:
+							attributes = pypi_json.loads(attributes)
+						except:
+							try:
+								attributes = ast.literal_eval(attributes)
+							except:
+								try:
+									attributes = pypi_json.loads(String(attributes).slice_dict())
+								except Exception as e:
+									if all_formats_allowed:
+										attributes = attributes
+									else:
+										raise Exceptions.InvalidUsage(f"<ResponseObject.attributes>: unable to parse a dict from attributes [str] [{attributes}].")
+			else:
+				if all_formats_allowed:
+					attributes = attributes
+				else:
+					raise Exceptions.InvalidUsage(f"<ResponseObject.attributes>: parameter [attributes] must be a [dict, dict in str format], not [{attributes.__class__.__name__}].")
+			if isinstance(attributes, (dict,Dictionary)):
+				_attributes_ = {}
+				for key, value in attributes.items():
+					_attributes_[key] = serialize(value, all_formats_allowed=True)
+				return _attributes_
+			else:
+				if attributes in ["true", "True", "TRUE", True]:
+					return True
+				elif attributes in ["false", "False", "FALSE", False]:
+					return False
+				elif attributes in ["null", "None", "Nan", None]:
+					return None
+				else:
+					integer = None
+					try:
+						if "." in attributes:
+							integer = float(attributes)
+						else:
+							integer = int(attributes)
+					except:
+						integer = None
+					if integer != None:
+						return integer
+					else:
+						return attributes
+		self.assign(serialize(attributes))
+		
 
 		# catch error so you can also init custom ResponseObjects.
 		try:
@@ -578,7 +633,7 @@ class ResponseObject(object):
 					del self[str(i)]
 				else:
 					del attributes[str(i)]
-			except KeyError: a=1
+			except: a=1
 		if serialize:
 			return self
 		else:
